#!/usr/bin/python

from sgcommmodel import *

class TestCase1Topology (SGCommunicationTopology):
    """
    Represents demo topology.

    Each custom topology must inherit SGCommunicationTopology.

    Note: circular topolgies are not supported without appropriate controller.
    """
    def __init__(self):

        c1 = CustomController("c1", "10.19.1.1", 6001)

        #NOTE: This is intended to be read from configuration file
        # Create AS
        s1 = Switch("s1", 10, c1);
        s2 = Switch("s2", 10, c1);
        s3 = Switch("s3", 10, c1, True);
        backhaul_as = AutonomousSystem( "BachHaulAS", [s1, s2, s3], [(s1, s3), (s2, s3)] )

        s4 = Switch("s4", 10, c1, True);
        core_as = AutonomousSystem( "CoreAS", [s4], [ ] )

        self.AutonomousSystems = [ backhaul_as, core_as ]

        self.links = [ (backhaul_as, core_as) ]

        ami_bw = TestCase1Topology.calculate_ami_bandwidth(sm_number = 250000, data_generation_rate = 300)
        self.flows = ( StreamFlow(ami_bw, (s1, 5059), (s4,), StreamFlow.CONSTANT_LOAD),
                       StreamFlow(1000, (s2, 5060), (s4,), StreamFlow.VARIABLE_LOAD),
                       CommandFlow(5, 10, 1024, 300, 1024, (s1, 5061), (s4, ) ) )

    @classmethod
    def calculate_ami_bandwidth(cls, sm_number, data_generation_rate, sm_packet_size = 512):
        """
        Calculates AMI bandwidth based on formula #.
        NOTE: data_generation_rate is expected in seconds
        """
        bw = sm_number * sm_packet_size / data_generation_rate / 1024
        return bw

class SampleTestCase:
    
    @classmethod
    def topology(cls):
        return TestCase1Topology()

    @classmethod
    def parameters(cls):
        parameters = EvaluationParameters(duration=120, test_name="TestCase1_evaluation", use_netflow = True, nodes_path="../nodes")
        return parameters
